@@ -1070,6 +1070,7 @@ class ScmCube:  # pylint:disable=too-many-public-methods
         areacell_scmcube=None,
         regions=None,
         cell_weights=None,
+        log_failure=False,
     ):
         """
         Get the scm timeseries weights
@@ -1103,6 +1104,10 @@ class ScmCube:  # pylint:disable=too-many-public-methods
             note that there seems to be nothing in Jones et al., *GMD*, 2016
             (`<https://doi.org/10.5194/gmd-9-2853-2016>`_).
 
+        log_failure : bool
+            Should regions which fail be logged? If no, failures are raised as
+            warnings.
+
         Returns
         -------
         dict of str: :obj:`np.ndarray`
@@ -1126,7 +1131,7 @@ class ScmCube:  # pylint:disable=too-many-public-methods
         weight_calculator = self._get_weight_calculator(cell_weights=cell_weights)
 
         regions = regions if regions is not None else DEFAULT_REGIONS
-        scm_weights = weight_calculator.get_weights(regions)
+        scm_weights = weight_calculator.get_weights(regions, log_failure=log_failure)
 
         return scm_weights
 
