@@ -5,6 +5,7 @@ This typically requires considering both the fraction of each cell which is of t
 """
 import logging
 import os
+import warnings
 from abc import ABC, abstractmethod
 from functools import lru_cache
 
@@ -552,23 +553,7 @@ def get_world_weights(
     )
 
 
-def get_ar6_region_weights(region):
-    """
-    Get a function to calculate the weights for a given AR6 region
-
-    AR6 regions defined in Iturbide et al., 2020
-    https://essd.copernicus.org/preprints/essd-2019-258/
-
-    Parameters
-    ----------
-    region : str
-        AR6 region to extract
-    Returns
-    -------
-    :func:`WeightFunc`
-        WeightFunc which weights out everything except the specified area
-    """
-
+def _get_regionmask_weights_calculation_function(region, regionmask_set):
     def _calculate_region_weights(weight_calculator, cube, **kwargs):
         if cube.netcdf_scm_realm == "land":
             weights = weight_calculator.get_weights_array_without_area_weighting(
@@ -583,10 +568,15 @@ def get_ar6_region_weights(region):
                 "World"
             )
 
-        region_mask = regionmask.defined_regions.ar6.all[[region]]
+        region_mask = regionmask_set[[region]]
 
         tdat_xr = xr.DataArray.from_iris(cube.cube)
-        mask = region_mask.mask_3D(tdat_xr)
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore",
+                ".*No gridpoint belongs to any region. Returning an all-False mask.*",
+            )
+            mask = region_mask.mask_3D(tdat_xr, drop=False)
 
         weights_xr = xr.DataArray(
             weights,
@@ -596,6 +586,7 @@ def get_ar6_region_weights(region):
             ],
             dims=["lat", "lon"],
         )
+
         weights = weights_xr.where(mask[0]).values
         weights[np.isnan(weights)] = 0
         return weights
@@ -603,6 +594,54 @@ def get_ar6_region_weights(region):
     return _calculate_region_weights
 
 
+def get_ar6_region_weights(region):
+    """
+    Get a function to calculate the weights for a given AR6 region
+
+    AR6 regions defined in Iturbide et al., 2020
+    https://essd.copernicus.org/preprints/essd-2019-258/
+
+    Parameters
+    ----------
+    region : str
+        AR6 region to extract
+
+    Returns
+    -------
+    :func:`WeightFunc`
+        WeightFunc which weights out everything except the specified area
+    """
+    calculate_region_weights = _get_regionmask_weights_calculation_function(
+        region, regionmask.defined_regions.ar6.all
+    )
+    return calculate_region_weights
+
+
+def get_natural_earth_50m_scale_region_weights(region):
+    """
+    Get a function to calculate the weights for a given Natural Earth defined region
+
+    We use the 50m scale from
+    `Natural Earth <https://www.naturalearthdata.com/>`_
+    and  the implementation provided by
+    `regionmask <https://regionmask.readthedocs.io/>`_.
+
+    Parameters
+    ----------
+    region : str
+        Natural Earth region to extract
+
+    Returns
+    -------
+    :func:`WeightFunc`
+        WeightFunc which weights out everything except the specified area
+    """
+    calculate_region_weights = _get_regionmask_weights_calculation_function(
+        region, regionmask.defined_regions.natural_earth.countries_50
+    )
+    return calculate_region_weights
+
+
 """dict: in-built functions to calculate weights for different regions without area weighting"""
 WEIGHTS_FUNCTIONS_WITHOUT_AREA_WEIGHTING = {
     "World": get_world_weights,
@@ -639,6 +678,14 @@ if has_regionmask:
             ar6_region_abbrev
         )
 
+    for (
+        natural_earth_region
+    ) in regionmask.defined_regions.natural_earth.countries_50.names:
+        region_name = "World|Natural Earth 50m|{}".format(natural_earth_region)
+        WEIGHTS_FUNCTIONS_WITHOUT_AREA_WEIGHTING[
+            region_name
+        ] = get_natural_earth_50m_scale_region_weights(natural_earth_region)
+
 
 class CubeWeightCalculator(ABC):
     """
@@ -786,15 +833,18 @@ class CubeWeightCalculator(ABC):
 
         return self._area_weights
 
-    def get_weights(self, weights_names):
+    def get_weights(self, weights_names, log_failure=False):
         """
         Get a number of weights
 
         Parameters
         ----------
-        weights_names: list of str
+        weights_names : list of str
             List of weights to attempt to load/calculate.
 
+        log_failure : bool
+            Should failures be logged? If no, failures are raised as warnings.
+
         Returns
         -------
         dict of str: :obj:`np.ndarray`
@@ -813,7 +863,11 @@ class CubeWeightCalculator(ABC):
                 weights_for_name = self.get_weights_array(name)
                 weights[name] = weights_for_name
             except InvalidWeightsError as e:
-                logger.warning("Failed to create '%s' weights: %s", name, str(e))
+                if log_failure:
+                    logger.warning("Failed to create '%s' weights: %s", name, str(e))
+                else:
+                    warn_str = "Failed to create '{}' weights: {}".format(name, str(e))
+                    warnings.warn(warn_str)
 
         return weights
 
