@@ -408,7 +408,7 @@ def test_auto_drop_land_regions(
 
     invalid_regions = set(in_regions) - set(out_regions)
     key_phrase = (
-        "Weights could not be calculated for the some regions, they will not "
+        "Weights could not be calculated for some regions, they will not "
         "appear in the output. Invalid regions: {}".format(invalid_regions)
     )
     if not safe:
@@ -464,7 +464,7 @@ def test_auto_drop_ocean_regions(
 
     invalid_regions = set(in_regions) - set(out_regions)
     key_phrase = (
-        "Weights could not be calculated for the some regions, they will not "
+        "Weights could not be calculated for some regions, they will not "
         "appear in the output. Invalid regions: {}".format(invalid_regions)
     )
     if not safe:
